==> domain_language_google_tag-8.x-1.0.tar.gz: domain_language_google_tag/src/Form/DomainLanguageGoogleTagSettingsForm.php <==
<?php

namespace Drupal\domain_language_google_tag\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\domain\DomainLoader;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Url;

/**
 * Configure Google_Analytics settings for this site.
 */
class DomainLanguageGoogleTagSettingsForm extends ConfigFormBase {

  /**
   * The config object for the domain_language_google_tag settings.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Drupal\domain\DomainLoader definition.
   *
   * @var \Drupal\domain\DomainLoader
   */
  protected $domainLoader;

  /**
   * Construct function.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\domain\DomainLoader $domain_loader
   *   Load the domain records.
   */
  public function __construct(ConfigFactoryInterface $config_factory, DomainLoader $domain_loader) {
    parent::__construct($config_factory);

    $this->domainLoader = $domain_loader;
  }

  /**
   * Create function return static domain loader configuration.
   *
   * @param Symfony\Component\DependencyInjection\ContainerInterface $container
   *   Load the ContainerInterface.
   *
   * @return \static
   *   return domain loader configuration.
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'), $container->get('domain.loader')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'domain_language_google_tag_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['domain_language_google_tag_settings.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $domains = $this->domainLoader->loadMultiple();

    $configFactory = $this->config('domain_language_google_tag_settings.settings');

    $form['general'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Multidomain and Multilanguage Google Analytics Settings'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
    ];

    $form['general']['global_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Google Tag global site ID'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $configFactory->get('global_id'),
      '#weight' => '0',
    ];

    if ($domains) {

      foreach ($domains as $domain) {

        $hostname = $domain->gethostname();
        if ($domain->id()) {

          $form['general'][$domain->id()] = [
            '#type' => 'fieldset',
            '#title' => $domain->get('name'),
            '#collapsible' => FALSE,
            '#collapsed' => FALSE,
          ];

          $form['general'][$domain->id()][$domain->id() . '_global'] = [
            '#type' => 'textfield',
            '#title' => $this->t('Google Tag ID for Domain: @hostname', ['@hostname' => $hostname]),
            '#maxlength' => 64,
            '#size' => 64,
            '#default_value' => $configFactory->get($domain->id() . '_global'),
            '#weight' => '0',
          ];

          $languages = $this->config('domain.language.' . $domain->id() . '.language.negotiation')->get('languages');

          foreach ($languages as $language) {
            if ($language != '***LANGUAGE_site_default***') {
              $form['general'][$domain->id()][$domain->id() . '_' . $language] = [
                '#type' => 'textfield',
                '#title' => $this->t('Google Tag ID for Domain: @hostname and Language: @lang', ['@hostname' => $hostname, '@lang' => $language]),
                '#maxlength' => 64,
                '#size' => 64,
                '#default_value' => $configFactory->get($domain->id() . '_' . $language),
                '#weight' => '0',
              ];
            }
          }

        }
      }
      return parent::buildForm($form, $form_state);
    }
    else {
      $url = Url::fromRoute('domain.admin');
      $domain_link = $this->l($this->t('Domain records'), $url);
      $form['title']['#markup'] = $this->t('There is no Domain record yet.Please create a domain records.See link: @domain_list', ['@domain_list' => $domain_link]);
      return $form;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('domain_language_google_tag_settings.settings');
    $domains = $this->domainLoader->loadOptionsList();

    $config->set('global_id', $form_state->getValue('global_id'))->save();

    foreach ($domains as $key => $value) {
      $config->set($key . '_global', $form_state->getValue($key . '_global'))->save();
      $languages = $this->config('domain.language.' . $key . '.language.negotiation')->get('languages');

      foreach ($languages as $language) {
        if ($language != '***LANGUAGE_site_default***') {
          $config->set($key . '_' . $language, $form_state->getValue($key . '_' . $language))->save();
        }
      }
    }

    parent::submitForm($form, $form_state);
  }

}

==> domain_language_google_tag-8.x-1.2.tar.gz: domain_language_google_tag/src/Form/DomainLanguageGoogleTagSettingsForm.php <==
<?php

namespace Drupal\domain_language_google_tag\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\domain\DomainLoader;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Url;

/**
 * Configure DomainLanguageGoogleTagSettingsForm settings for this site.
 */
class DomainLanguageGoogleTagSettingsForm extends ConfigFormBase {

  /**
   * The config object for the domain_language_google_tag settings.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Drupal\domain\DomainLoader definition.
   *
   * @var \Drupal\domain\DomainLoader
   */
  protected $domainLoader;

  /**
   * Construct function.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\domain\DomainLoader $domain_loader
   *   Load the domain records.
   */
  public function __construct(ConfigFactoryInterface $config_factory, DomainLoader $domain_loader) {
    parent::__construct($config_factory);

    $this->domainLoader = $domain_loader;
  }

  /**
   * Create function return static domain loader configuration.
   *
   * @param Symfony\Component\DependencyInjection\ContainerInterface $container
   *   Load the ContainerInterface.
   *
   * @return \static
   *   return domain loader configuration.
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'), $container->get('domain.loader')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'domain_language_google_tag_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['domain_language_google_tag_settings.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $domains = $this->domainLoader->loadMultiple();

    $configFactory = $this->config('domain_language_google_tag_settings.settings');

    $form['general'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Multidomain and Multilanguage Google Tag Manager Settings'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
    ];

    $form['general']['global_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Google Tag global site ID'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $configFactory->get('global_id'),
      '#weight' => '0',
    ];

    if ($domains) {

      foreach ($domains as $domain) {

        $hostname = $domain->gethostname();
        if ($domain->id()) {

          $form['general'][$domain->id()] = [
            '#type' => 'fieldset',
            '#title' => $domain->get('name'),
            '#collapsible' => FALSE,
            '#collapsed' => FALSE,
          ];

          $form['general'][$domain->id()][$domain->id() . '_global'] = [
            '#type' => 'textfield',
            '#title' => $this->t('Google Tag ID for Domain: @hostname', ['@hostname' => $hostname]),
            '#maxlength' => 64,
            '#size' => 64,
            '#default_value' => $configFactory->get($domain->id() . '_global'),
            '#weight' => '0',
          ];

          $languages = $this->config('domain.language.' . $domain->id() . '.language.negotiation')->get('languages');

          foreach ($languages as $language) {
            if ($language != '***LANGUAGE_site_default***') {
              $form['general'][$domain->id()][$domain->id() . '_' . $language] = [
                '#type' => 'textfield',
                '#title' => $this->t('Google Tag ID for Domain: @hostname and Language: @lang', ['@hostname' => $hostname, '@lang' => $language]),
                '#maxlength' => 64,
                '#size' => 64,
                '#default_value' => $configFactory->get($domain->id() . '_' . $language),
                '#weight' => '0',
              ];
            }
          }

        }
      }
      return parent::buildForm($form, $form_state);
    }
    else {
      $url = Url::fromRoute('domain.admin');
      $domain_link = $this->l($this->t('Domain records'), $url);
      $form['title']['#markup'] = $this->t('There is no Domain record yet.Please create a domain records.See link: @domain_list', ['@domain_list' => $domain_link]);
      return $form;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('domain_language_google_tag_settings.settings');
    $domains = $this->domainLoader->loadOptionsList();

    $config->set('global_id', $form_state->getValue('global_id'))->save();

    foreach ($domains as $key => $value) {
      $config->set($key . '_global', $form_state->getValue($key . '_global'))->save();
      $languages = $this->config('domain.language.' . $key . '.language.negotiation')->get('languages');

      foreach ($languages as $language) {
        if ($language != '***LANGUAGE_site_default***') {
          $config->set($key . '_' . $language, $form_state->getValue($key . '_' . $language))->save();
        }
      }
    }

    parent::submitForm($form, $form_state);
  }

}
